"""Coerce strings of YAML origin to required types."""

import pytest
from mklists.rules import Rule


def test_coerce_target_sortorder_as_integer():
    """Field 1 (target_sortorder) must be an integer."""
    rule_obj = Rule(1, "NOW", "a", "b", 2)
    rule_obj._coerce_target_sortorder_as_integer()
    assert isinstance(rule_obj.target_sortorder, int)


def test_coerce_target_sortorder_as_integer_given_good_string():
    """Field 1 (target_sortorder) must be an integer."""
    rule_obj = Rule("1", "NOW", "a", "b", "2")
    rule_obj._coerce_target_sortorder_as_integer()
    assert isinstance(rule_obj.target_sortorder, int)
    assert rule_obj.target_sortorder == 2


def test_coerce_target_sortorder_as_integer_raise_exception_given_bad_string():
    """Field 1 (target_sortorder) must be an integer."""
    rule_obj = Rule("1 2", "NOW", "a", "b", "1 2")
    with pytest.raises(SystemExit):
        rule_obj._coerce_target_sortorder_as_integer()


def test_coerce_target_sortorder_as_integer_raise_exception_given_non_integer():
    """Perversely, int(1.2) evaluates to 1; improbable edge case?"""
    rule_obj = Rule(1.2, "NOW", "a", "b", 1.2)
    rule_obj._coerce_target_sortorder_as_integer()
    assert isinstance(rule_obj.target_sortorder, int)
    assert rule_obj.target_sortorder == 1
